@@ -2,14 +2,14 @@
 use crate::point::Point;
 
 /**
- * The decluster algorithm cycles through the points set calculating the distnace between each pair of points. If that distance is greater than `max_distance`
-the point is marked for removal by the vec's `retain` function.
+ The decluster algorithm cycles through the points set calculating the distance between each pair of points. If that distance is greater than the `min_distance` then the point
+ is marked for removal by the vec's `retain` function.
 
-Note that one a point is marked for removal there is no need to process it further.
+Note that once a point is marked for removal there is no need to process it further.
 
 # Arguments
     * points - the vec of Point structures
-    * min_distance - the minimum allowed separtion distance between points
+    * min_distance - the minimum distance allowed between points
 */
 pub fn decluster(points: &mut Vec<Point>, min_distance: f64) {
     for i in 0..points.len() {
